@@ -14,95 +14,80 @@
 #include <string.h>
 
 /* default commands implementation */
-static bool
-girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
-    bool unmap)
-{
-  typedef struct gdk_keyboard_button_s
-  {
+static bool girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list, bool unmap) {
+  typedef struct gdk_keyboard_button_s {
     char* identifier;
     int keyval;
   } gdk_keyboard_button_t;
 
   static const gdk_keyboard_button_t gdk_keyboard_buttons[] = {
-    {"BackSpace", GDK_KEY_BackSpace},
-    {"CapsLock",  GDK_KEY_Caps_Lock},
-    {"Down",      GDK_KEY_Down},
-    {"Esc",       GDK_KEY_Escape},
-    {"F10",       GDK_KEY_F10},
-    {"F11",       GDK_KEY_F11},
-    {"F12",       GDK_KEY_F12},
-    {"F1",        GDK_KEY_F1},
-    {"F2",        GDK_KEY_F2},
-    {"F3",        GDK_KEY_F3},
-    {"F4",        GDK_KEY_F4},
-    {"F5",        GDK_KEY_F5},
-    {"F6",        GDK_KEY_F6},
-    {"F7",        GDK_KEY_F7},
-    {"F8",        GDK_KEY_F8},
-    {"F9",        GDK_KEY_F9},
-    {"Left",      GDK_KEY_Left},
-    {"PageDown",  GDK_KEY_Page_Down},
-    {"PageUp",    GDK_KEY_Page_Up},
-    {"Home",      GDK_KEY_Home},
-    {"End",       GDK_KEY_End},
-    {"Return",    GDK_KEY_Return},
-    {"Right",     GDK_KEY_Right},
-    {"Space",     GDK_KEY_space},
-    {"Super",     GDK_KEY_Super_L},
-    {"Tab",       GDK_KEY_Tab},
-    {"ShiftTab",  GDK_KEY_ISO_Left_Tab},
-    {"Up",        GDK_KEY_Up},
-    {"Print",     GDK_KEY_Print},
-    {"KPLeft",    GDK_KEY_KP_Left},
-    {"KPRight",   GDK_KEY_KP_Right},
-    {"KPUp",      GDK_KEY_KP_Up},
-    {"KPDown",    GDK_KEY_KP_Down}
+      {"BackSpace", GDK_KEY_BackSpace},
+      {"CapsLock", GDK_KEY_Caps_Lock},
+      {"Down", GDK_KEY_Down},
+      {"Esc", GDK_KEY_Escape},
+      {"F10", GDK_KEY_F10},
+      {"F11", GDK_KEY_F11},
+      {"F12", GDK_KEY_F12},
+      {"F1", GDK_KEY_F1},
+      {"F2", GDK_KEY_F2},
+      {"F3", GDK_KEY_F3},
+      {"F4", GDK_KEY_F4},
+      {"F5", GDK_KEY_F5},
+      {"F6", GDK_KEY_F6},
+      {"F7", GDK_KEY_F7},
+      {"F8", GDK_KEY_F8},
+      {"F9", GDK_KEY_F9},
+      {"Left", GDK_KEY_Left},
+      {"PageDown", GDK_KEY_Page_Down},
+      {"PageUp", GDK_KEY_Page_Up},
+      {"Home", GDK_KEY_Home},
+      {"End", GDK_KEY_End},
+      {"Return", GDK_KEY_Return},
+      {"Right", GDK_KEY_Right},
+      {"Space", GDK_KEY_space},
+      {"Super", GDK_KEY_Super_L},
+      {"Tab", GDK_KEY_Tab},
+      {"ShiftTab", GDK_KEY_ISO_Left_Tab},
+      {"Up", GDK_KEY_Up},
+      {"Print", GDK_KEY_Print},
+      {"KPLeft", GDK_KEY_KP_Left},
+      {"KPRight", GDK_KEY_KP_Right},
+      {"KPUp", GDK_KEY_KP_Up},
+      {"KPDown", GDK_KEY_KP_Down},
   };
 
-  typedef struct gdk_mouse_button_s
-  {
+  typedef struct gdk_mouse_button_s {
     char* identifier;
     int button;
   } gdk_mouse_button_t;
 
   static const gdk_mouse_button_t gdk_mouse_buttons[] = {
-    {"Button1", GIRARA_MOUSE_BUTTON1},
-    {"Button2", GIRARA_MOUSE_BUTTON2},
-    {"Button3", GIRARA_MOUSE_BUTTON3},
-    {"Button4", GIRARA_MOUSE_BUTTON4},
-    {"Button5", GIRARA_MOUSE_BUTTON5},
-    {"Button6", GIRARA_MOUSE_BUTTON6},
-    {"Button7", GIRARA_MOUSE_BUTTON7},
-    {"Button8", GIRARA_MOUSE_BUTTON8},
-    {"Button9", GIRARA_MOUSE_BUTTON9}
+      {"Button1", GIRARA_MOUSE_BUTTON1}, {"Button2", GIRARA_MOUSE_BUTTON2}, {"Button3", GIRARA_MOUSE_BUTTON3},
+      {"Button4", GIRARA_MOUSE_BUTTON4}, {"Button5", GIRARA_MOUSE_BUTTON5}, {"Button6", GIRARA_MOUSE_BUTTON6},
+      {"Button7", GIRARA_MOUSE_BUTTON7}, {"Button8", GIRARA_MOUSE_BUTTON8}, {"Button9", GIRARA_MOUSE_BUTTON9},
   };
 
-  typedef struct event_type_s
-  {
+  typedef struct event_type_s {
     char* identifier;
     int event;
   } event_type_t;
 
   static const event_type_t event_types[] = {
-    {"motion",       GIRARA_EVENT_MOTION_NOTIFY},
-    {"scroll_up",    GIRARA_EVENT_SCROLL_UP},
-    {"scroll_down",  GIRARA_EVENT_SCROLL_DOWN},
-    {"scroll_left",  GIRARA_EVENT_SCROLL_LEFT},
-    {"scroll_right", GIRARA_EVENT_SCROLL_RIGHT}
+      {"motion", GIRARA_EVENT_MOTION_NOTIFY},      {"scroll_up", GIRARA_EVENT_SCROLL_UP},
+      {"scroll_down", GIRARA_EVENT_SCROLL_DOWN},   {"scroll_left", GIRARA_EVENT_SCROLL_LEFT},
+      {"scroll_right", GIRARA_EVENT_SCROLL_RIGHT},
   };
 
-  typedef struct mouse_event_s
-  {
+  typedef struct mouse_event_s {
     char* identifier;
     int event;
   } mouse_event_t;
 
   static const mouse_event_t mouse_events[] = {
-    {"button-pressed",   GIRARA_EVENT_BUTTON_PRESS},
-    {"2-button-pressed", GIRARA_EVENT_2BUTTON_PRESS},
-    {"3-button-pressed", GIRARA_EVENT_2BUTTON_PRESS},
-    {"button-released",  GIRARA_EVENT_BUTTON_RELEASE}
+      {"button-pressed", GIRARA_EVENT_BUTTON_PRESS},
+      {"2-button-pressed", GIRARA_EVENT_2BUTTON_PRESS},
+      {"3-button-pressed", GIRARA_EVENT_2BUTTON_PRESS},
+      {"button-released", GIRARA_EVENT_BUTTON_RELEASE},
   };
 
   const size_t number_of_arguments = girara_list_size(argument_list);
@@ -110,8 +95,8 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
   unsigned int limit = (unmap == true) ? 1 : 2;
   if (number_of_arguments < limit) {
     girara_warning("Invalid number of arguments passed: %zu instead of at least %u", number_of_arguments, limit);
-    girara_notify(session, GIRARA_ERROR,
-        _("Invalid number of arguments passed: %zu instead of at least %u"), number_of_arguments, limit);
+    girara_notify(session, GIRARA_ERROR, _("Invalid number of arguments passed: %zu instead of at least %u"),
+                  number_of_arguments, limit);
     return false;
   }
 
@@ -155,7 +140,7 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
   }
 
   if (is_mode == true) {
-    tmp = girara_list_nth(argument_list, ++current_command);
+    tmp        = girara_list_nth(argument_list, ++current_command);
     tmp_length = g_utf8_strlen(tmp, -1);
     tmp_size   = strlen(tmp);
   }
@@ -169,33 +154,33 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
     /* Multi key shortcut */
     if (strchr(tmp, '-') != NULL && g_utf8_get_char(g_utf8_offset_to_pointer(tmp, 1)) == '-' && tmp_length > 2) {
       switch (g_utf8_get_char(tmp)) {
-        case 'S':
-          shortcut_mask = GDK_SHIFT_MASK;
-          break;
-        case 'A':
-        case 'M':
-          shortcut_mask = GDK_MOD1_MASK;
-          break;
-        case 'C':
-          shortcut_mask = GDK_CONTROL_MASK;
-          break;
-        default:
-          girara_warning("Invalid modifier in %s", tmp);
-          girara_notify(session, GIRARA_ERROR, _("Invalid modifier in %s"), tmp);
-          g_free(tmp);
-          return false;
+      case 'S':
+        shortcut_mask = GDK_SHIFT_MASK;
+        break;
+      case 'A':
+      case 'M':
+        shortcut_mask = GDK_MOD1_MASK;
+        break;
+      case 'C':
+        shortcut_mask = GDK_CONTROL_MASK;
+        break;
+      default:
+        girara_warning("Invalid modifier in %s", tmp);
+        girara_notify(session, GIRARA_ERROR, _("Invalid modifier in %s"), tmp);
+        g_free(tmp);
+        return false;
       }
 
       /* Single key */
       if (tmp_length == 3) {
         shortcut_key = gdk_unicode_to_keyval(g_utf8_get_char(g_utf8_offset_to_pointer(tmp, 2)));
-      /* Possible special key */
+        /* Possible special key */
       } else {
         bool found = false;
         for (unsigned int i = 0; i < LENGTH(gdk_keyboard_buttons); i++) {
           if (g_strcmp0(tmp + 2, gdk_keyboard_buttons[i].identifier) == 0) {
             shortcut_key = gdk_keyboard_buttons[i].keyval;
-            found = true;
+            found        = true;
             break;
           }
         }
@@ -203,17 +188,17 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
         for (unsigned int i = 0; i < LENGTH(gdk_mouse_buttons); i++) {
           if (!g_strcmp0(tmp + 2, gdk_mouse_buttons[i].identifier)) {
             shortcut_mouse_button = gdk_mouse_buttons[i].button;
-            mouse_event = true;
-            found = true;
+            mouse_event           = true;
+            found                 = true;
             break;
           }
         }
 
         for (unsigned int i = 0; i < LENGTH(event_types); i++) {
           if (!g_strcmp0(tmp + 2, event_types[i].identifier)) {
-            event_type = event_types[i].event;
+            event_type  = event_types[i].event;
             mouse_event = true;
-            found = true;
+            found       = true;
             break;
           }
         }
@@ -225,13 +210,13 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
           return false;
         }
       }
-    /* Possible special key */
+      /* Possible special key */
     } else {
       bool found = false;
       for (unsigned int i = 0; i < LENGTH(gdk_keyboard_buttons); i++) {
         if (g_strcmp0(tmp, gdk_keyboard_buttons[i].identifier) == 0) {
           shortcut_key = gdk_keyboard_buttons[i].keyval;
-          found = true;
+          found        = true;
           break;
         }
       }
@@ -239,17 +224,17 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
       for (unsigned int i = 0; i < LENGTH(gdk_mouse_buttons); i++) {
         if (!g_strcmp0(tmp, gdk_mouse_buttons[i].identifier)) {
           shortcut_mouse_button = gdk_mouse_buttons[i].button;
-          mouse_event = true;
-          found = true;
+          mouse_event           = true;
+          found                 = true;
           break;
         }
       }
 
       for (unsigned int i = 0; i < LENGTH(event_types); i++) {
         if (!g_strcmp0(tmp, event_types[i].identifier)) {
-          event_type = event_types[i].event;
+          event_type  = event_types[i].event;
           mouse_event = true;
-          found = true;
+          found       = true;
           break;
         }
       }
@@ -263,10 +248,10 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
     }
 
     g_free(tmp);
-  /* Single key shortcut */
+    /* Single key shortcut */
   } else if (tmp_length == 1) {
     shortcut_key = gdk_unicode_to_keyval(g_utf8_get_char(tmp));
-  /* Buffer command */
+    /* Buffer command */
   } else {
     shortcut_buffer_command = g_strdup(tmp);
   }
@@ -275,7 +260,7 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
   bool mouse_mode = false;
   if (unmap == false) {
     if (++current_command < number_of_arguments) {
-      tmp = girara_list_nth(argument_list, current_command);
+      tmp        = girara_list_nth(argument_list, current_command);
       tmp_length = g_utf8_strlen(tmp, -1);
       tmp_size   = strlen(tmp);
 
@@ -292,7 +277,7 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
         for (unsigned int i = 0; i < LENGTH(mouse_events); i++) {
           if (!g_strcmp0(tmp_inner, mouse_events[i].identifier)) {
             event_type = mouse_events[i].event;
-            found = true;
+            found      = true;
             break;
           }
         }
@@ -315,8 +300,8 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
     limit = (mouse_mode == true) ? 3 : 2;
     if (number_of_arguments < limit) {
       girara_warning("Invalid number of arguments passed: %zu instead of at least %u", number_of_arguments, limit);
-      girara_notify(session, GIRARA_ERROR,
-          _("Invalid number of arguments passed: %zu instead of at least %u"), number_of_arguments, limit);
+      girara_notify(session, GIRARA_ERROR, _("Invalid number of arguments passed: %zu instead of at least %u"),
+                    number_of_arguments, limit);
       return false;
     }
 
@@ -352,7 +337,7 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
   /* Check for passed argument */
   if (unmap == false) {
     if (++current_command < number_of_arguments) {
-      tmp = (char*) girara_list_nth(argument_list, current_command);
+      tmp = (char*)girara_list_nth(argument_list, current_command);
 
       for (size_t idx = 0; idx != girara_list_size(session_private->config.argument_mappings); ++idx) {
         girara_argument_mapping_t* mapping = girara_list_nth(session_private->config.argument_mappings, idx);
@@ -365,10 +350,10 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
       /* If no known argument is passed we save it in the data field */
       if (shortcut_argument_n == 0) {
         shortcut_argument_data = tmp;
-      /* If a known argument is passed and there are still more arguments,
-       * we save the next one in the data field */
+        /* If a known argument is passed and there are still more arguments,
+         * we save the next one in the data field */
       } else if (++current_command < number_of_arguments) {
-        tmp = (char*) girara_list_nth(argument_list, current_command);
+        tmp                    = (char*)girara_list_nth(argument_list, current_command);
         shortcut_argument_data = tmp;
       }
     }
@@ -376,19 +361,17 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
 
   if (mouse_event == false) {
     if (unmap == true) {
-      girara_shortcut_remove(session, shortcut_mask, shortcut_key,
-          shortcut_buffer_command, shortcut_mode);
+      girara_shortcut_remove(session, shortcut_mask, shortcut_key, shortcut_buffer_command, shortcut_mode);
     } else {
-      girara_shortcut_add(session, shortcut_mask, shortcut_key, shortcut_buffer_command,
-          shortcut_function, shortcut_mode, shortcut_argument_n, shortcut_argument_data);
+      girara_shortcut_add(session, shortcut_mask, shortcut_key, shortcut_buffer_command, shortcut_function,
+                          shortcut_mode, shortcut_argument_n, shortcut_argument_data);
     }
   } else {
     if (unmap == true) {
-      girara_mouse_event_remove(session, shortcut_mask, shortcut_mouse_button,
-          shortcut_mode);
+      girara_mouse_event_remove(session, shortcut_mask, shortcut_mouse_button, shortcut_mode);
     } else {
-      girara_mouse_event_add(session, shortcut_mask, shortcut_mouse_button,
-          shortcut_function, shortcut_mode, event_type, shortcut_argument_n, shortcut_argument_data);
+      girara_mouse_event_add(session, shortcut_mask, shortcut_mouse_button, shortcut_function, shortcut_mode,
+                             event_type, shortcut_argument_n, shortcut_argument_data);
     }
   }
 
@@ -399,23 +382,16 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
   return true;
 }
 
-bool
-girara_cmd_map(girara_session_t* session, girara_list_t* argument_list)
-{
+bool girara_cmd_map(girara_session_t* session, girara_list_t* argument_list) {
   return girara_cmd_map_unmap(session, argument_list, false);
 }
 
-bool
-girara_cmd_unmap(girara_session_t* session, girara_list_t* argument_list)
-{
+bool girara_cmd_unmap(girara_session_t* session, girara_list_t* argument_list) {
   return girara_cmd_map_unmap(session, argument_list, true);
 }
 
-
-bool
-girara_cmd_quit(girara_session_t* session, girara_list_t* UNUSED(argument_list))
-{
-  girara_argument_t arg = { GIRARA_HIDE, NULL };
+bool girara_cmd_quit(girara_session_t* session, girara_list_t* UNUSED(argument_list)) {
+  girara_argument_t arg = {.n = GIRARA_HIDE, .data = NULL};
   girara_isc_completion(session, &arg, NULL, 0);
 
   gtk_main_quit();
@@ -423,9 +399,7 @@ girara_cmd_quit(girara_session_t* session, girara_list_t* UNUSED(argument_list))
   return true;
 }
 
-bool
-girara_cmd_set(girara_session_t* session, girara_list_t* argument_list)
-{
+bool girara_cmd_set(girara_session_t* session, girara_list_t* argument_list) {
   const size_t number_of_arguments = girara_list_size(argument_list);
 
   if (number_of_arguments == 0) {
@@ -440,7 +414,7 @@ girara_cmd_set(girara_session_t* session, girara_list_t* argument_list)
   }
 
   /* search for existing setting */
-  char* name = (char*) girara_list_nth(argument_list, 0);
+  char* name = (char*)girara_list_nth(argument_list, 0);
   if (name == NULL) {
     return false;
   }
@@ -455,43 +429,39 @@ girara_cmd_set(girara_session_t* session, girara_list_t* argument_list)
   if (number_of_arguments == 1) {
     /* display setting*/
     switch (girara_setting_get_type(setting)) {
-      case BOOLEAN:
-      {
-        /* for compatibility reasons: toogle the setting */
-        bool value = false;
-        girara_setting_get_value(setting, &value);
-        bool tmp = !value;
-        girara_setting_set_value(session, setting, &tmp);
-        girara_notify(session, GIRARA_INFO, "%s: %s", name, tmp ? _("true") : _("false"));
-        break;
-      }
-      case FLOAT:
-      {
-        float value = 0;
-        girara_setting_get_value(setting, &value);
-        girara_notify(session, GIRARA_INFO, "%s: %f", name, value);
-        break;
-      }
-      case INT:
-      {
-        int value = 0;
-        girara_setting_get_value(setting, &value);
-        girara_notify(session, GIRARA_INFO, "%s: %i", name, value);
-        break;
-      }
-      case STRING:
-      {
-        char* str = NULL;
-        girara_setting_get_value(setting, &str);
-        girara_notify(session, GIRARA_INFO, "%s: %s", name, str ? str : "(NULL)");
-        g_free(str);
-        break;
-      }
-      default:
-        return false;
+    case BOOLEAN: {
+      /* for compatibility reasons: toogle the setting */
+      bool value = false;
+      girara_setting_get_value(setting, &value);
+      bool tmp = !value;
+      girara_setting_set_value(session, setting, &tmp);
+      girara_notify(session, GIRARA_INFO, "%s: %s", name, tmp ? _("true") : _("false"));
+      break;
+    }
+    case FLOAT: {
+      float value = 0;
+      girara_setting_get_value(setting, &value);
+      girara_notify(session, GIRARA_INFO, "%s: %f", name, value);
+      break;
+    }
+    case INT: {
+      int value = 0;
+      girara_setting_get_value(setting, &value);
+      girara_notify(session, GIRARA_INFO, "%s: %i", name, value);
+      break;
+    }
+    case STRING: {
+      char* str = NULL;
+      girara_setting_get_value(setting, &str);
+      girara_notify(session, GIRARA_INFO, "%s: %s", name, str ? str : "(NULL)");
+      g_free(str);
+      break;
+    }
+    default:
+      return false;
     }
   } else {
-    char* value = (char*) girara_list_nth(argument_list, 1);
+    char* value = (char*)girara_list_nth(argument_list, 1);
     if (value == NULL) {
       girara_warning("No value defined for option: %s", name);
       girara_notify(session, GIRARA_ERROR, _("No value defined for option: %s"), name);
@@ -500,35 +470,33 @@ girara_cmd_set(girara_session_t* session, girara_list_t* argument_list)
 
     /* update value */
     switch (girara_setting_get_type(setting)) {
-      case BOOLEAN:
-        if (g_strcmp0(value, "false") == 0 || g_strcmp0(value, "0") == 0) {
-          bool b = false;
-          girara_setting_set_value(session, setting, &b);
-        } else if (g_strcmp0(value, "true") == 0 || g_strcmp0(value, "1") == 0) {
-          bool b = true;
-          girara_setting_set_value(session, setting, &b);
-        } else {
-          girara_warning("Unknown value for option: %s", name);
-          girara_notify(session, GIRARA_ERROR, _("Unknown value for option: %s"), name);
-        }
-        break;
-      case FLOAT:
-      {
-        float f = g_ascii_strtod(value, NULL);
-        girara_setting_set_value(session, setting, &f);
-        break;
+    case BOOLEAN:
+      if (g_strcmp0(value, "false") == 0 || g_strcmp0(value, "0") == 0) {
+        bool b = false;
+        girara_setting_set_value(session, setting, &b);
+      } else if (g_strcmp0(value, "true") == 0 || g_strcmp0(value, "1") == 0) {
+        bool b = true;
+        girara_setting_set_value(session, setting, &b);
+      } else {
+        girara_warning("Unknown value for option: %s", name);
+        girara_notify(session, GIRARA_ERROR, _("Unknown value for option: %s"), name);
       }
-      case INT:
-      {
-        int i = atoi(value);
-        girara_setting_set_value(session, setting, &i);
-        break;
-      }
-      case STRING:
-        girara_setting_set_value(session, setting, value);
-        break;
-      default:
-        return false;
+      break;
+    case FLOAT: {
+      float f = g_ascii_strtod(value, NULL);
+      girara_setting_set_value(session, setting, &f);
+      break;
+    }
+    case INT: {
+      int i = atoi(value);
+      girara_setting_set_value(session, setting, &i);
+      break;
+    }
+    case STRING:
+      girara_setting_set_value(session, setting, value);
+      break;
+    default:
+      return false;
     }
   }
 
@@ -576,7 +544,7 @@ bool girara_special_command_add(girara_session_t* session, char identifier, gira
   g_return_val_if_fail(session != NULL, false);
   g_return_val_if_fail(function != NULL, false);
 
-  girara_argument_t argument = {argument_n, argument_data};
+  girara_argument_t argument = {.n = argument_n, .data = argument_data};
 
   /* search for existing special command */
   for (size_t idx = 0; idx != girara_list_size(session->bindings.special_commands); ++idx) {
@@ -617,9 +585,7 @@ void girara_command_free(girara_command_t* command) {
   g_free(command);
 }
 
-bool
-girara_cmd_exec(girara_session_t* session, girara_list_t* argument_list)
-{
+bool girara_cmd_exec(girara_session_t* session, girara_list_t* argument_list) {
   if (session == NULL || argument_list == NULL) {
     return true;
   }
@@ -627,19 +593,17 @@ girara_cmd_exec(girara_session_t* session, girara_list_t* argument_list)
   return girara_exec_with_argument_list(session, argument_list);
 }
 
-bool
-girara_command_run(girara_session_t* session, const char* input)
-{
+bool girara_command_run(girara_session_t* session, const char* input) {
   /* parse input */
   gchar** argv = NULL;
-  gint    argc = 0;
+  gint argc    = 0;
 
   if (g_shell_parse_argv(input, &argc, &argv, NULL) == FALSE) {
     girara_debug("Failed to parse argument.");
     return false;
   }
 
-  gchar *cmd = argv[0];
+  gchar* cmd = argv[0];
 
   /* search commands */
   for (size_t idx = 0; idx != girara_list_size(session->bindings.commands); ++idx) {
