@@ -13,40 +13,36 @@
 #include "shortcuts.h"
 
 static GtkEventBox* girara_completion_row_create(const char*, const char*, bool);
-static void girara_completion_row_set_color(girara_session_t*, GtkEventBox*, int);
+static void girara_completion_row_set_color(GtkEventBox*, int);
 
 /* completion */
-struct girara_internal_completion_entry_s
-{
-  bool group; /**< The entry is a group */
-  char* value; /**< Name of the entry */
+struct girara_internal_completion_entry_s {
   GtkEventBox* widget; /**< Eventbox widget */
+  char* value;         /**< Name of the entry */
+  bool group;          /**< The entry is a group */
 };
 
 /**
  * Structure of a completion element
  */
-struct girara_completion_element_s
-{
-  char *value; /**> Name of the completion element */
-  char *description; /**> Description of the completion element */
+struct girara_completion_element_s {
+  char* value;       /**> Name of the completion element */
+  char* description; /**> Description of the completion element */
 };
 
 /**
  * Structure of a completion group
  */
-struct girara_completion_group_s
-{
-  char *value; /**> Name of the completion element */
-  girara_list_t *elements; /**> Elements of the completion group */
+struct girara_completion_group_s {
+  char* value;             /**> Name of the completion element */
+  girara_list_t* elements; /**> Elements of the completion group */
 };
 
 /**
  * Structure of a completion object
  */
-struct girara_completion_s
-{
-  girara_list_t *groups; /**> Containing completion groups */
+struct girara_completion_s {
+  girara_list_t* groups; /**> Containing completion groups */
 };
 
 typedef struct girara_internal_completion_entry_s girara_internal_completion_entry_t;
@@ -64,7 +60,7 @@ static void completion_element_free(girara_completion_element_t* element) {
 
 girara_completion_t* girara_completion_init(void) {
   girara_completion_t* completion = g_malloc(sizeof(girara_completion_t));
-  completion->groups              = girara_list_new2((girara_free_function_t)girara_completion_group_free);
+  completion->groups              = girara_list_new_with_free((girara_free_function_t)girara_completion_group_free);
 
   return completion;
 }
@@ -73,7 +69,7 @@ girara_completion_group_t* girara_completion_group_create(girara_session_t* UNUS
   girara_completion_group_t* group = g_malloc(sizeof(girara_completion_group_t));
 
   group->value    = name ? g_strdup(name) : NULL;
-  group->elements = girara_list_new2((girara_free_function_t)completion_element_free);
+  group->elements = girara_list_new_with_free((girara_free_function_t)completion_element_free);
 
   if (group->elements == NULL) {
     g_free(group);
@@ -83,11 +79,9 @@ girara_completion_group_t* girara_completion_group_create(girara_session_t* UNUS
   return group;
 }
 
-void
-girara_completion_add_group(girara_completion_t* completion, girara_completion_group_t* group)
-{
+void girara_completion_add_group(girara_completion_t* completion, girara_completion_group_t* group) {
   g_return_if_fail(completion != NULL);
-  g_return_if_fail(group      != NULL);
+  g_return_if_fail(group != NULL);
 
   girara_list_append(completion->groups, group);
 }
@@ -103,7 +97,9 @@ void girara_completion_group_free(girara_completion_group_t* group) {
 }
 
 void girara_completion_free(girara_completion_t* completion) {
-  g_return_if_fail(completion != NULL);
+  if (completion == NULL) {
+    return;
+  }
 
   girara_list_free(completion->groups);
   /* free completion */
@@ -122,13 +118,12 @@ void girara_completion_group_add_element(girara_completion_group_t* group, const
   girara_list_append(group->elements, new_element);
 }
 
-bool
-girara_isc_completion(girara_session_t* session, girara_argument_t* argument, girara_event_t* UNUSED(event), unsigned int UNUSED(t))
-{
+bool girara_isc_completion(girara_session_t* session, girara_argument_t* argument, girara_event_t* UNUSED(event),
+                           unsigned int UNUSED(t)) {
   g_return_val_if_fail(session != NULL, false);
 
   /* get current text */
-  gchar *input = gtk_editable_get_chars(GTK_EDITABLE(session->gtk.inputbar_entry), 0, -1);
+  gchar* input = gtk_editable_get_chars(GTK_EDITABLE(session->gtk.inputbar_entry), 0, -1);
   if (input == NULL) {
     return false;
   }
@@ -141,7 +136,7 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
   }
 
   gchar** elements = NULL;
-  gint    n_parameter = 0;
+  gint n_parameter = 0;
   if (input_length > 1) {
     if (g_shell_parse_argv(input + 1, &n_parameter, &elements, NULL) == FALSE) {
       g_free(input);
@@ -156,22 +151,22 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
     elements[0] = g_strdup("");
   }
 
-  if (n_parameter == 1 && input[input_length-1] == ' ') {
+  if (n_parameter == 1 && input[input_length - 1] == ' ') {
     n_parameter += 1;
   }
 
   g_free(input);
 
   /* get current values */
-  gchar *current_command   = (elements[0] != NULL && elements[0][0] != '\0') ? g_strdup(elements[0]) : NULL;
-  gchar *current_parameter = (elements[0] != NULL && elements[1] != NULL)    ? g_strdup(elements[1]) : NULL;
+  gchar* current_command   = (elements[0] != NULL && elements[0][0] != '\0') ? g_strdup(elements[0]) : NULL;
+  gchar* current_parameter = (elements[0] != NULL && elements[1] != NULL) ? g_strdup(elements[1]) : NULL;
 
   size_t current_command_length = current_command ? strlen(current_command) : 0;
 
   static GList* entries           = NULL;
   static GList* entries_current   = NULL;
-  static char *previous_command   = NULL;
-  static char *previous_parameter = NULL;
+  static char* previous_command   = NULL;
+  static char* previous_parameter = NULL;
   static bool command_mode        = true;
   static size_t previous_length   = 0;
 
@@ -184,13 +179,10 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
    *   no current command is given
    *   there is only one completion entry
    */
-  if ( (argument->n == GIRARA_HIDE) ||
+  if ((argument->n == GIRARA_HIDE) ||
       (current_parameter && previous_parameter && g_strcmp0(current_parameter, previous_parameter)) ||
       (current_command && previous_command && g_strcmp0(current_command, previous_command)) ||
-      (input_length != previous_length) ||
-      is_single_entry
-    )
-  {
+      (input_length != previous_length) || is_single_entry) {
     if (session->gtk.results != NULL) {
       /* destroy elements */
       for (GList* element = entries; element; element = g_list_next(element)) {
@@ -246,7 +238,7 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
     }
 
     if (n_parameter <= 1) {
-    /* based on commands */
+      /* based on commands */
       command_mode = true;
 
       /* create command rows */
@@ -325,7 +317,7 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
          * XXX: the last argument should only be current_paramater ... but
          * therefore the completion functions would need to handle NULL correctly
          * (see cc_open in zathura). */
-        girara_completion_t *result = command->completion(session, current_parameter ? current_parameter : "");
+        girara_completion_t* result = command->completion(session, current_parameter ? current_parameter : "");
 
         if (result == NULL || result->groups == NULL) {
           g_free(current_parameter);
@@ -383,7 +375,8 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
   unsigned int n_elements = g_list_length(entries);
   if (entries != NULL && n_elements > 0) {
     if (n_elements > 1) {
-      girara_completion_row_set_color(session, ((girara_internal_completion_entry_t *) entries_current->data)->widget, GIRARA_NORMAL);
+      girara_completion_row_set_color(((girara_internal_completion_entry_t*)entries_current->data)->widget,
+                                      GIRARA_NORMAL);
 
       bool next_group = FALSE;
 
@@ -404,20 +397,22 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
           entries_current = entry;
         }
 
-        if (((girara_internal_completion_entry_t*) entries_current->data)->group) {
+        if (((girara_internal_completion_entry_t*)entries_current->data)->group) {
           if (command_mode == false && (argument->n == GIRARA_NEXT_GROUP || argument->n == GIRARA_PREVIOUS_GROUP)) {
             next_group = TRUE;
           }
           continue;
         } else {
-          if (command_mode == false && (next_group == 0) && (argument->n == GIRARA_NEXT_GROUP || argument->n == GIRARA_PREVIOUS_GROUP)) {
+          if (command_mode == false && (next_group == 0) &&
+              (argument->n == GIRARA_NEXT_GROUP || argument->n == GIRARA_PREVIOUS_GROUP)) {
             continue;
           }
           break;
         }
       }
 
-      girara_completion_row_set_color(session, ((girara_internal_completion_entry_t *) entries_current->data)->widget, GIRARA_HIGHLIGHT);
+      girara_completion_row_set_color(((girara_internal_completion_entry_t*)entries_current->data)->widget,
+                                      GIRARA_HIGHLIGHT);
 
       /* hide other items */
       unsigned int n_completion_items = 15;
@@ -429,29 +424,25 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
 
       GList* tmpentry = entries;
       for (unsigned int i = 0; i < n_elements; i++) {
-        if (
-            (i >= (current_item - lh) && (i <= current_item + uh)) ||
-            (i < n_completion_items && current_item < lh) ||
-            (i >= (n_elements - n_completion_items) && (current_item >= (n_elements - uh)))
-          )
-        {
-          gtk_widget_show(GTK_WIDGET(((girara_internal_completion_entry_t*) tmpentry->data)->widget));
+        if ((i >= (current_item - lh) && (i <= current_item + uh)) || (i < n_completion_items && current_item < lh) ||
+            (i >= (n_elements - n_completion_items) && (current_item >= (n_elements - uh)))) {
+          gtk_widget_show(GTK_WIDGET(((girara_internal_completion_entry_t*)tmpentry->data)->widget));
         } else {
-          gtk_widget_hide(GTK_WIDGET(((girara_internal_completion_entry_t*) tmpentry->data)->widget));
+          gtk_widget_hide(GTK_WIDGET(((girara_internal_completion_entry_t*)tmpentry->data)->widget));
         }
 
         tmpentry = g_list_next(tmpentry);
       }
     } else {
-      gtk_widget_hide(GTK_WIDGET(((girara_internal_completion_entry_t*) (g_list_nth(entries, 0))->data)->widget));
+      gtk_widget_hide(GTK_WIDGET(((girara_internal_completion_entry_t*)(g_list_nth(entries, 0))->data)->widget));
     }
 
     /* update text */
     char* temp;
-    char* escaped_value = girara_escape_string(((girara_internal_completion_entry_t *) entries_current->data)->value);
+    char* escaped_value = girara_escape_string(((girara_internal_completion_entry_t*)entries_current->data)->value);
     if (command_mode == true) {
       char* space = (n_elements == 1) ? " " : "";
-      temp = g_strconcat(":", escaped_value, space, NULL);
+      temp        = g_strconcat(":", escaped_value, space, NULL);
     } else {
       temp = g_strconcat(":", previous_command, " ", escaped_value, NULL);
     }
@@ -480,31 +471,29 @@ girara_isc_completion(girara_session_t* session, girara_argument_t* argument, gi
   return false;
 }
 
-static GtkEventBox*
-girara_completion_row_create(const char* command, const char* description, bool group)
-{
-  GtkBox *col = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0));
+static GtkEventBox* girara_completion_row_create(const char* command, const char* description, bool group) {
+  GtkBox* col = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0));
 
-  GtkEventBox *row = GTK_EVENT_BOX(gtk_event_box_new());
+  GtkEventBox* row = GTK_EVENT_BOX(gtk_event_box_new());
 
-  GtkLabel *show_command     = GTK_LABEL(gtk_label_new(NULL));
-  GtkLabel *show_description = GTK_LABEL(gtk_label_new(NULL));
+  GtkLabel* show_command     = GTK_LABEL(gtk_label_new(NULL));
+  GtkLabel* show_description = GTK_LABEL(gtk_label_new(NULL));
 
   gtk_widget_set_halign(GTK_WIDGET(show_command), GTK_ALIGN_START);
   gtk_widget_set_valign(GTK_WIDGET(show_command), GTK_ALIGN_START);
   gtk_widget_set_halign(GTK_WIDGET(show_description), GTK_ALIGN_END);
   gtk_widget_set_valign(GTK_WIDGET(show_description), GTK_ALIGN_START);
 
-  gtk_label_set_use_markup(show_command,     TRUE);
+  gtk_label_set_use_markup(show_command, TRUE);
   gtk_label_set_use_markup(show_description, TRUE);
 
   gtk_label_set_ellipsize(show_command, PANGO_ELLIPSIZE_END);
   gtk_label_set_ellipsize(show_description, PANGO_ELLIPSIZE_END);
 
-  gchar* c = g_markup_printf_escaped(FORMAT_COMMAND,     command ? command : "");
-  gchar* d = g_markup_printf_escaped(FORMAT_DESCRIPTION, description ? description : "");
-  gtk_label_set_markup(show_command,     c);
-  gtk_label_set_markup(show_description, d);
+  gchar* c = command ? g_markup_printf_escaped(FORMAT_COMMAND, command) : NULL;
+  gchar* d = description ? g_markup_printf_escaped(FORMAT_DESCRIPTION, description) : NULL;
+  gtk_label_set_markup(show_command, command ? c : "");
+  gtk_label_set_markup(show_description, description ? d : "");
   g_free(c);
   g_free(d);
 
@@ -514,7 +503,7 @@ girara_completion_row_create(const char* command, const char* description, bool
   widget_add_class(GTK_WIDGET(row), class);
   widget_add_class(GTK_WIDGET(col), class);
 
-  gtk_box_pack_start(GTK_BOX(col), GTK_WIDGET(show_command),     TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(col), GTK_WIDGET(show_command), TRUE, TRUE, 0);
   gtk_box_pack_start(GTK_BOX(col), GTK_WIDGET(show_description), TRUE, TRUE, 0);
 
   gtk_container_add(GTK_CONTAINER(row), GTK_WIDGET(col));
@@ -523,11 +512,8 @@ girara_completion_row_create(const char* command, const char* description, bool
   return row;
 }
 
-static void
-girara_completion_row_set_color(girara_session_t* session, GtkEventBox* row, int mode)
-{
-  g_return_if_fail(session != NULL);
-  g_return_if_fail(row     != NULL);
+static void girara_completion_row_set_color(GtkEventBox* row, int mode) {
+  g_return_if_fail(row != NULL);
 
   GtkBox* col     = GTK_BOX(gtk_bin_get_child(GTK_BIN(row)));
   GList* items    = gtk_container_get_children(GTK_CONTAINER(col));
